@@ -93,11 +93,13 @@ class AppSetup(Controller):
         self.app.log.info(f'deploying plugin')
         try:
             plugin_name = os.path.split(os.getcwd())[1]
-            print(plugin_name)
+            backend_path = os.path.join(os.getcwd(), 'backend')
+            print(backend_path)
             backend_image_tag = f'{plugin_name}-backend:latest'
             print(backend_image_tag)
             print(self.container_registry)
-            os.system(f'cd {self.backend_path} && docker build -t {backend_image_tag} .')
+            os.system(f'cd {self.backend_path}')
+            os.system(f'docker build -t {backend_image_tag} .')
             os.system(f'docker tag {backend_image_tag} {self.container_registry}/{backend_image_tag}')
             os.system(f'docker push {self.container_registry}/{backend_image_tag}')
         except OSError as e:
